package com.jqtx.windows.job;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.jqtx.infrastructure.oss.starter.config.OssUtils;
import com.jqtx.windows.component.CreditComponent;
import com.jqtx.windows.component.LoanComponent;
import com.jqtx.windows.component.enums.ZNPostUrlEnum;
import com.jqtx.windows.component.model.CreditModel;
import com.jqtx.windows.component.model.LoanModel;
import com.jqtx.windows.component.model.ZyJsonResult;
import com.jqtx.windows.utils.AbcHttpClient;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.time.DateFormatUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.UUID;

@Component
@Slf4j
public class CreditThirdDataJob {
    @Autowired
    private CreditComponent creditComponent;

    @Autowired
    private AbcHttpClient abcHttpClient;

    @Autowired
    private LoanComponent loanComponent;

    @Autowired
    private OssUtils ossUtils;

    @XxlJob("creditThirdDataJob")
    public void run() {
        List<CreditModel> creditModels = creditComponent.getListModelByCreditThirdStatus("INIT");
        creditModels.parallelStream().forEach(c -> {
            JSONObject thirdCredit = new JSONObject();
            thirdCredit.put("reqNo", c.getOrderNo());
            thirdCredit.put("type", "01");
            ZyJsonResult zyJsonResult = abcHttpClient.postRequest(thirdCredit.toJSONString(), ZNPostUrlEnum.CREDIT_QUERY.getCode());
            if("00".equalsIgnoreCase(zyJsonResult.getStatus())||"01".equalsIgnoreCase(zyJsonResult.getStatus())){
                JSONArray jsonArray = zyJsonResult.getExternalInfo();
                processThirdData(c.getClientCell(), c.getOrderNo(), jsonArray);
            }
        });

        List<CreditModel> withdraw = creditComponent.getListModelByCreditThirdStatus("INIT-WITHDRAW");
        withdraw.parallelStream().forEach(w->{
            LoanModel loanModel= loanComponent.getByOrderNo(w.getOrderNo());
            JSONObject thirdCredit = new JSONObject();
            thirdCredit.put("reqNo", loanModel.getLoanNo());
            thirdCredit.put("type", "02");

            ZyJsonResult zyJsonResult = abcHttpClient.postRequest(thirdCredit.toJSONString(), ZNPostUrlEnum.CREDIT_QUERY.getCode());
            if("00".equalsIgnoreCase(zyJsonResult.getStatus())||"01".equalsIgnoreCase(zyJsonResult.getStatus())){
                JSONArray jsonArray = zyJsonResult.getExternalInfo();
                processThirdData(w.getClientCell(), w.getOrderNo(), jsonArray);
            }

        });
    }

    private void processThirdData(String clientCell, String orderNo, JSONArray jsonArray) {
        JSONObject thirdData = new JSONObject();
        for (int i = 0; i < jsonArray.size(); i++) {
            JSONObject jsonObject = (JSONObject) jsonArray.get(i);
            log.info("dataSource:[{}],data:[{}]", jsonObject.getString("dataSource"), jsonObject.getJSONObject("data"));
            if ("TENCENT_FRAUD_VIP".equals(jsonObject.getString("dataSource"))) {
                   thirdData.put("PD_TENCENT_FRAUD_VIP", jsonObject.getJSONObject("data"));
            } else if ("TENCENT_FRAUD_SUMMIT".equals(jsonObject.getString("dataSource"))) {
                thirdData.put("PD_TENCENT_FRAUD", jsonObject.getJSONObject("data"));
            } else if ("RONG360_BLACK_LIST".equals(jsonObject.getString("dataSource"))) {
                thirdData.put("PD_R360_ZHDZPF_V2", jsonObject.getJSONObject("data"));
            } else if ("RONG360_ZXFV3_SCORE".equals(jsonObject.getString("dataSource"))) {
                thirdData.put("PD_R360_ZHDZPF", jsonObject.getJSONObject("data"));
            } else {
                thirdData.put(jsonObject.getString("dataSource"), jsonObject.getJSONObject("data"));
            }

        }
        StringBuffer filePath = new StringBuffer();

        filePath.append("zhenong").append("/").append(DateFormatUtils.format(new Date(), "yyyyMMdd")).append("/").append(orderNo).append("/");
        String pdfFileName = clientCell + UUID.randomUUID();
        ossUtils.upStringObject(filePath + pdfFileName, thirdData.toString());
        CreditModel creditModel = new CreditModel();
        creditModel.setCreditThirdStatus("FINISHED");
        creditModel.setCreditThirdUrl(filePath + pdfFileName);
        creditComponent.updateByOrderNo(orderNo, creditModel);
    }


}
